==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/plugins/enzymes/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>FindEnzymesDialog</name>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="14"/>
        <source>Restriction Enzymes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="42"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="47"/>
        <source>Accession</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="52"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="57"/>
        <source>Sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="62"/>
        <source>Organizm / Details</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="71"/>
        <source>Selected enzymes:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="87"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="110"/>
        <source>Enzymes file..</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="117"/>
        <source>Select All</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="124"/>
        <source>Select None</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="131"/>
        <source>Invert selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="145"/>
        <source>REBASE Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="171"/>
        <source>Range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="177"/>
        <source>Whole sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="200"/>
        <source>Selected range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="227"/>
        <source>Custom range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="256"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="293"/>
        <source>Filter by number of results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="311"/>
        <source>Minimum results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="343"/>
        <source>Maximum results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="394"/>
        <source>Select enzymes to search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="414"/>
        <source>Run</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="424"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::EnzymesADVContext</name>
    <message>
        <location filename="../src/EnzymesPlugin.cpp" line="62"/>
        <source>Restriction sites..</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::EnzymesIO</name>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="17"/>
        <source>Bairoch format</source>
        <translation> </translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="26"/>
        <source>Unsupported URI type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="39"/>
        <source>Unsupported enzymes file format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="49"/>
        <source>Non-nucleic enzyme alphabet: &apos;%1&apos;, alphabet: %2, sequence &apos;%3&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="85"/>
        <source>Line is too long: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="137"/>
        <source>Illegal cut pos: %1, line %2</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::EnzymesPlugin</name>
    <message>
        <location filename="../src/EnzymesPlugin.cpp" line="31"/>
        <source>Tools to find and mark restriction enzymes cut sites in DNA sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesPlugin.cpp" line="30"/>
        <source>Restriction analysis</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindEnzymesDialog</name>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="76"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="77"/>
        <source>Any</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="135"/>
        <source>File not exists: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="142"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="227"/>
        <source>Number of enzymes: %1, selected %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="232"/>
        <source>Select enzyme database file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="298"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="304"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="317"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="330"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="352"/>
        <source>Error!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="298"/>
        <source>No enzymes selected!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="317"/>
        <source>Minimum hit value must be lesser or equal then maximum!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="330"/>
        <source>Invalid range!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="352"/>
        <source>No enzyme selected!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindEnzymesTask</name>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="61"/>
        <source>Find Enzymes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="74"/>
        <location filename="../src/FindEnzymesTask.cpp" line="165"/>
        <source>Number of results exceed %1, stopping</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="133"/>
        <source>Found %1 restriction sites</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindEnzymesToAnnotationsTask</name>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="21"/>
        <source>Find and store enzymes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="32"/>
        <source>Annotation table does not exist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="37"/>
        <source>Annotation table is read-only</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindSingleEnzymeTask</name>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="146"/>
        <source>Find enzyme &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="158"/>
        <source>Find enzyme &apos;%1&apos; parallel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="178"/>
        <source>Non-nucleic enzyme alphabet: %1, enzyme: %2, skipping..</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LoadEnzymeFileTask</name>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="171"/>
        <source>Load enzymes from %1</source>
        <translation></translation>
    </message>
</context>
</TS>

==> ugene_1.7.1+repack.orig.tar.gz: ugene-1.7.1/src/plugins/enzymes/transl/english.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>FindEnzymesDialog</name>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="14"/>
        <source>Restriction Enzymes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="42"/>
        <source>Name</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="47"/>
        <source>Accession</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="52"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="57"/>
        <source>Sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="62"/>
        <source>Organizm / Details</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="71"/>
        <source>Selected enzymes:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="87"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="110"/>
        <source>Enzymes file..</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="117"/>
        <source>Select All</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="124"/>
        <source>Select None</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="131"/>
        <source>Select by length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="138"/>
        <source>Invert selection</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="145"/>
        <source>Save selection..</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="159"/>
        <source>REBASE Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="185"/>
        <source>Range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="191"/>
        <source>Whole sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="214"/>
        <source>Selected range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="241"/>
        <source>Custom range</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="270"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="315"/>
        <source>Circular</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="327"/>
        <source>Filter by number of results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="345"/>
        <source>Minimum results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="377"/>
        <source>Maximum results</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="428"/>
        <source>Select enzymes to search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="448"/>
        <source>Run</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/FindEnzymesDialog.ui" line="458"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::EnzymesADVContext</name>
    <message>
        <location filename="../src/EnzymesPlugin.cpp" line="62"/>
        <source>Restriction sites..</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::EnzymesIO</name>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="17"/>
        <source>Bairoch format</source>
        <translation> </translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="26"/>
        <location filename="../src/EnzymesIO.cpp" line="66"/>
        <location filename="../src/EnzymesIO.cpp" line="73"/>
        <source>Unsupported URI type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="39"/>
        <location filename="../src/EnzymesIO.cpp" line="86"/>
        <source>Unsupported enzymes file format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="49"/>
        <source>Non-nucleic enzyme alphabet: &apos;%1&apos;, alphabet: %2, sequence &apos;%3&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="119"/>
        <location filename="../src/EnzymesIO.cpp" line="215"/>
        <source>Line is too long: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="171"/>
        <source>Illegal cut pos: %1, line %2</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::EnzymesPlugin</name>
    <message>
        <location filename="../src/EnzymesPlugin.cpp" line="31"/>
        <source>Tools to find and mark restriction enzymes cut sites in DNA sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/EnzymesPlugin.cpp" line="30"/>
        <source>Restriction analysis</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindEnzymesDialog</name>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="77"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="78"/>
        <source>Any</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="140"/>
        <source>File not exists: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="147"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="185"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="191"/>
        <source>New enzymes database has been saved.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="192"/>
        <source>Do you want to work with new database?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="266"/>
        <source>Number of enzymes: %1, selected %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="271"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="345"/>
        <source>Select enzyme database file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="307"/>
        <source>Minimum length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="307"/>
        <source>Enter minimum length of recognition sites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="369"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="375"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="388"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="401"/>
        <location filename="../src/FindEnzymesDialog.cpp" line="424"/>
        <source>Error!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="369"/>
        <source>No enzymes selected!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="388"/>
        <source>Minimum hit value must be lesser or equal then maximum!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="401"/>
        <source>Invalid range!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesDialog.cpp" line="424"/>
        <source>No enzyme selected!</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindEnzymesTask</name>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="64"/>
        <source>Find Enzymes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="78"/>
        <location filename="../src/FindEnzymesTask.cpp" line="219"/>
        <source>Number of results exceed %1, stopping</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="171"/>
        <source>Found %1 restriction sites</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindEnzymesToAnnotationsTask</name>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="22"/>
        <source>Find and store enzymes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="35"/>
        <source>Annotation table does not exist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="40"/>
        <source>Annotation table is read-only</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::FindSingleEnzymeTask</name>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="184"/>
        <source>Find enzyme &apos;%1&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="209"/>
        <source>Find enzyme &apos;%1&apos; parallel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/FindEnzymesTask.cpp" line="235"/>
        <source>Non-nucleic enzyme alphabet: %1, enzyme: %2, skipping..</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::LoadEnzymeFileTask</name>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="246"/>
        <source>Load enzymes from %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::SaveEnzymeFileTask</name>
    <message>
        <location filename="../src/EnzymesIO.cpp" line="258"/>
        <source>Save enzymes to %1</source>
        <translation></translation>
    </message>
</context>
</TS>
